@@ -209,7 +209,7 @@ def add_numbers(labels, style='per_element'):
     return add_label_indices(labels, style=style)
 
 
-def add_label_indices(labels, style='per_element'):
+def add_label_indices(labels, style='per_element', start_index=1):
     """
     Add label indexing to atomic symbols - either element or per atom.
 
@@ -221,6 +221,8 @@ def add_label_indices(labels, style='per_element'):
         {'per_element', 'sequential'}
             'per_element' : Index by element e.g. Dy1, Dy2, N1, N2, etc.
             'sequential' : Index the atoms 1->N regardless of element
+    start_index : int
+        integer at which indexing will start
 
     Returns
     -------
@@ -233,7 +235,7 @@ def add_label_indices(labels, style='per_element'):
 
     # Just number the atoms 1->N regardless of element
     if style == 'sequential':
-        labels_wn = ['{}{:d}'.format(lab, it+1)
+        labels_wn = ['{}{:d}'.format(lab, it+start_index)
                      for (it, lab) in enumerate(labels)]
 
     # Index by element Dy1, Dy2, N1, N2, etc.
@@ -241,7 +243,7 @@ def add_label_indices(labels, style='per_element'):
         # Get list of unique elements
         atoms = set(labels_nn)
         # Create dict to keep track of index of current atom of each element
-        atom_count = {atom: 1 for atom in atoms}
+        atom_count = {atom: start_index for atom in atoms}
         # Create labelled list of elements
         labels_wn = []
         for lab in labels_nn:
